@@ -303,9 +303,8 @@ class Ies:
                     self.summary[1] = {'add': new_index, 'kappa': max_kappa,
                                        'confusion_matrix': self._evaluate_selection(selected_indices)[1]}
             else:
-                log("No second endmember found. Returning without result.")
-                set_progress(progress_int)
-                return None
+                set_progress(100)
+                raise Exception("No second endmember found. Returning without result.")
         else:
             log("1: second loop skipped because forced library contained more than one endmember")
             progress_int = progress_int + 1
